@@ -738,6 +738,7 @@ class DashboardStats(models.Model):
         operation_field_choice: Optional[str],
         user: Union[User, AnonymousUser],
     ):
+        configuration = configuration.copy()
         m2m = self.get_multi_series_criteria(configuration)
         reload_data = configuration.pop("reload", None) in ("true", "True")
         reload_all_data = configuration.pop("reload_all", None) in ("true", "True")
@@ -746,7 +747,7 @@ class DashboardStats(models.Model):
             "stats": self,
             "operation": operation_choice,
             "operation_field_name": operation_field_choice,
-            "time_scale": interval,
+            "time_scale": interval.value,
             "multiple_series_choice": criteria,
             "dynamic_choices": get_dynamic_choices_array(configuration),
         }
@@ -757,9 +758,8 @@ class DashboardStats(models.Model):
             gaps = self.get_gaps(
                 reload_data, reload_all_data, time_since, time_until, interval, cached_query
             )
-            bulk = []
             for gap_since, gap_until in gaps:
-                cached_query.filter(date__gte=gap_since, date__lte=gap_until).delete()
+                bulk = []
                 values = self.get_multi_time_series(
                     configuration,
                     gap_since,
@@ -790,7 +790,8 @@ class DashboardStats(models.Model):
                             ),
                         ]
                         i += 1
-            CachedValue.objects.bulk_create(bulk)
+                cached_query.filter(date__gte=gap_since, date__lte=gap_until).delete()
+                CachedValue.objects.bulk_create(bulk)
 
         return transform_cached_values(
             cached_query.values("date", "filtered_value", "value"),
@@ -1005,7 +1006,7 @@ class CachedValue(models.Model):
     )
     date = models.DateTimeField()
     time_scale = models.CharField(
-        verbose_name=_("Default time scale"),
+        verbose_name=_("Time scale"),
         null=False,
         blank=False,
         default="days",
