@@ -65,7 +65,8 @@ class ChartDataView(TemplateView):
             context["graph_title"] = dashboard_stats.graph_title
             return context
 
-        configuration: Dict[str, Union[str, List[str]]] = self.request.GET.dict()
+        dict = self.request.GET
+        configuration: Dict[str, Union[str, List[str]]] = {item: dict[item] for item in dict}
         remove_multiple_keys(configuration, ["csrfmiddlewaretoken", "_", "graph_key"])
         selected_interval: Interval = Interval(
             configuration.pop("select_box_interval", interval) or dashboard_stats.default_time_scale
@@ -119,11 +120,6 @@ class ChartDataView(TemplateView):
             context["graph_title"] = dashboard_stats.graph_title
             logger.exception(e)
             return context
-        criteria = dashboard_stats.get_multi_series_criteria(configuration)
-        if criteria:
-            choices = criteria.get_dynamic_choices(time_since, time_until)
-        else:
-            choices = {}
 
         ydata_serie: Dict[str, List[int]] = {}
         names = {}
@@ -140,9 +136,7 @@ class ChartDataView(TemplateView):
                 y_key = "y%i" % serie_i_map[key]
                 if y_key not in ydata_serie:
                     ydata_serie[y_key] = []
-                    names["name%i" % serie_i_map[key]] = str(
-                        choices[key][1] if key in choices else key
-                    )
+                    names["name%i" % serie_i_map[key]] = str(key)
                 ydata_serie[y_key].append(value if value else 0)
 
         context["extra"] = {
